import {
  select,
  csv,
  scaleLinear,
  max,
  scaleBand,
  axisLeft,
  axisBottom
} from 'd3';

export const barChart = (selection, props) => {
  const {
    xValue,
    xAxisLabel='Graduate Program Category',
    yValue,
    yAxisLabel,
    margin,
    width,
    height,
    data
  } = props;
  
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  
  const yScale = scaleLinear()
    .domain([0, max(data, yValue)])
    .range([innerHeight, 0]);
  
  const xScale = scaleBand()
    .domain(data.map(xValue))
    .range([0, innerWidth])
    .padding(0.1);
  
  const g = selection.selectAll('.container').data([null]);
  const gEnter = g
    .enter().append('g')
      .attr('class', 'container');
  gEnter
    .merge(g)
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  // y axis
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10);
  
  const yAxisG = g.select('.y-axis');
  const yAxisGEnter = gEnter
    .append('g')
      .attr('class', 'y-axis');
  
  yAxisG
    .merge(yAxisGEnter)
    .call(yAxis)
    .selectAll('.domain').remove()
    .selectAll('text');
  
  const yAxisLabelText = yAxisGEnter
    .append('text')
      .attr('class', 'axis-label')
      .attr('y', -100)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
    .merge(yAxisG.select('.axis-label'))
      .attr('x', -innerHeight/2)
      //.text(yAxisLabel);
  
  // x axis
  const xAxis = axisBottom(xScale)
    .tickSize(0);
  
  const xAxisG = g.select('.x-axis');
  const xAxisGEnter = gEnter
    .append('g')
      .attr('class', 'x-axis');
  xAxisG
    .merge(xAxisGEnter)
      .attr('transform', `translate(-10, ${innerHeight})`)
      .call(xAxis)
      .selectAll('text')
        .attr('text-anchor', 'start')
        .attr('transform', `rotate(-90)`)
        .attr('font-weight', 'bold');
  
  const xAxisLabelText = xAxisGEnter
  .append('text')
    .attr('class', 'axis-label')
    .attr('y', 30)
    .attr('fill', 'black')
  .merge(xAxisG.select('.axis-label'))
    .attr('x', innerWidth / 2)
    .text(xAxisLabel);
  
  const rects = g.merge(gEnter)
    .selectAll('rect').data(data);;;
  rects
    .enter().append('rect')
      .attr('x', function(d, i) {
        return xScale.bandwidth() * i;
      })
      .attr('y', innerHeight)
    .merge(rects)
    .transition().duration(1000)
      .attr('x', d => xScale(xValue(d)))
      .attr('y', d => yScale(yValue(d)))
      .attr('height', d => innerHeight - yScale(yValue(d)))
      .attr('width', xScale.bandwidth());
};
