import {
  select,
  csv,
  scaleLinear,
  max,
  scaleBand,
  axisLeft,
  axisBottom
} from 'd3';

import { dropdownMenu } from './dropdownMenu';
import { barChart } from './barChart';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

let data;
let yColumn;

const onYColumnClicked = column => {
  yColumn = column;
  render();
};

const render = () => {
  
  select('#y-menus')
    .call(dropdownMenu, {
      options: data.columns.slice(1),
      onOptionClicked: onYColumnClicked,
      selectedOption: yColumn
    });
  
  
  svg.call(barChart, {
    yValue: d => d[yColumn],
    yAxisLabel: yColumn,
    xValue: d => d.Major_category,
    margin: { top: 20, right: 40, bottom: 100, left: 100 },
    width,
    height,
    data
    
  });
};

csv('https://vizhub.com/ilovemanu/datasets/grad_by_cate.csv').then(loadedData => {
  
  data = loadedData;
  data.forEach(d => {
    
    d.Grad_total = +d.Grad_total;
    d.Grad_employed = +d.Grad_employed;
    d.Grad_unemployed = +d.Grad_unemployed;
    d.Grad_unemployment_rate = +d.Grad_unemployment_rate;
    d.Grad_median = +d.Grad_median;
    d.Grad_full_time_year_round = +d.Grad_full_time_year_round;
    d.Grad_P25 = +d.Grad_P25;
    d.Grad_P75 = +d.Grad_P75;
    
  });
  yColumn = data.columns[1];
  render();
});